@@ -7,7 +7,7 @@
   Copyright (C) Adrian Baddeley, Jens Oehlschlaegel and Rolf Turner 2000-2013
   Licence: GNU Public Licence >= 2
 
-  $Revision: 1.3 $     $Date: 2013/05/27 02:09:10 $
+  $Revision: 1.5 $     $Date: 2013/11/03 03:37:39 $
 
   Function definitions are #included from knndist.h and knnXdist.h
 
@@ -99,6 +99,51 @@ double sqrt();
 
 /* --------------- two distinct point patterns X and Y --------------- */
 
+/* general interface */
+
+void knnXinterface(n1, x1, y1, id1, 
+		   n2, x2, y2, id2, 
+		   kmax,
+		   exclude, wantdist, wantwhich,
+		   nnd, nnwhich, 
+		   huge)
+     /* inputs */
+     int *n1, *n2;
+     double *x1, *y1, *x2, *y2, *huge;
+     int *id1, *id2;
+     int *kmax;
+     /* options */
+     int *exclude, *wantdist, *wantwhich;
+     /* outputs */
+     double *nnd;
+     int *nnwhich;
+     /* some inputs + outputs are not used in all functions */
+{
+  void knnX(), knnXdist(), knnXwhich();
+  void knnXE(), knnXEdist(), knnXEwhich();
+  int ex, di, wh;
+  ex = (*exclude != 0);
+  di = (*wantdist != 0);
+  wh = (*wantwhich != 0);
+  if(ex) {
+    if(di && wh) {
+      knnX(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } else if(di) {
+      knnXdist(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } else if(wh) {
+      knnXwhich(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } 
+  } else {
+    if(di && wh) {
+      knnXE(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } else if(di) {
+      knnXEdist(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } else if(wh) {
+      knnXEwhich(n1, x1, y1, id1, n2, x2, y2, id2, nnd, nnwhich, huge);
+    } 
+  }
+}
+
 /* 
    knnXdist
 
